# XBCF python package

## Installation

### From PyPi

To install XBART from PYPI use `pip install xbcausalforest`

### From source

#### linux/MacOS

For general installation run `./build_py.sh -d`.

If you are making changes to the C++ files in \xbart please download SWIG.
Once installed, run `./build_py.sh -s -d`

#### PC

Use `build_py3.cmd` (requires SWIG)

# Example

TBD


